@@ -4,7 +4,7 @@ dim.Rcpp_Rmumps <- function (x) x$dim()
 nrow.Rcpp_Rmumps <- function (x) x$nrow()
 ncol.Rcpp_Rmumps <- function (x) x$ncol()
 print.Rcpp_Rmumps <- function (x, ...) x$print()
-show.Rcpp_Rmumps <- function (x) x$show()
+show.Rcpp_Rmumps <- function (object) object$show()
 
 solvet <- function(a, b, ...) UseMethod("solvet")
 solvet.Rcpp_Rmumps <- function (a, b, ...) if(missing(b)) base::t(a$inv()) else a$solvet(b)
